# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 64.4.0-v202407221832
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ConditionNotificationOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'creator': 'IdentityPreviewV1',
        'enabled': 'bool',
        'id': 'str',
        'name': 'str',
        'workbooks': 'dict(str, str)'
    }

    attribute_map = {
        'creator': 'creator',
        'enabled': 'enabled',
        'id': 'id',
        'name': 'name',
        'workbooks': 'workbooks'
    }

    def __init__(self, creator=None, enabled=None, id=None, name=None, workbooks=None):
        """
        ConditionNotificationOutputV1 - a model defined in Swagger
        """

        self._creator = None
        self._enabled = None
        self._id = None
        self._name = None
        self._workbooks = None

        if creator is not None:
          self.creator = creator
        if enabled is not None:
          self.enabled = enabled
        if id is not None:
          self.id = id
        if name is not None:
          self.name = name
        if workbooks is not None:
          self.workbooks = workbooks

    @property
    def creator(self):
        """
        Gets the creator of this ConditionNotificationOutputV1.

        :return: The creator of this ConditionNotificationOutputV1.
        :rtype: IdentityPreviewV1
        """
        return self._creator

    @creator.setter
    def creator(self, creator):
        """
        Sets the creator of this ConditionNotificationOutputV1.

        :param creator: The creator of this ConditionNotificationOutputV1.
        :type: IdentityPreviewV1
        """

        self._creator = creator

    @property
    def enabled(self):
        """
        Gets the enabled of this ConditionNotificationOutputV1.
        Whether the associated condition monitor is enabled or not

        :return: The enabled of this ConditionNotificationOutputV1.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this ConditionNotificationOutputV1.
        Whether the associated condition monitor is enabled or not

        :param enabled: The enabled of this ConditionNotificationOutputV1.
        :type: bool
        """
        if enabled is None:
            raise ValueError("Invalid value for `enabled`, must not be `None`")

        self._enabled = enabled

    @property
    def id(self):
        """
        Gets the id of this ConditionNotificationOutputV1.
        ID of the associated condition monitor

        :return: The id of this ConditionNotificationOutputV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ConditionNotificationOutputV1.
        ID of the associated condition monitor

        :param id: The id of this ConditionNotificationOutputV1.
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id

    @property
    def name(self):
        """
        Gets the name of this ConditionNotificationOutputV1.
        Notification name

        :return: The name of this ConditionNotificationOutputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ConditionNotificationOutputV1.
        Notification name

        :param name: The name of this ConditionNotificationOutputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def workbooks(self):
        """
        Gets the workbooks of this ConditionNotificationOutputV1.
        The workbooks that contain the conditions associated with the condition monitor

        :return: The workbooks of this ConditionNotificationOutputV1.
        :rtype: dict(str, str)
        """
        return self._workbooks

    @workbooks.setter
    def workbooks(self, workbooks):
        """
        Sets the workbooks of this ConditionNotificationOutputV1.
        The workbooks that contain the conditions associated with the condition monitor

        :param workbooks: The workbooks of this ConditionNotificationOutputV1.
        :type: dict(str, str)
        """
        if workbooks is None:
            raise ValueError("Invalid value for `workbooks`, must not be `None`")

        self._workbooks = workbooks

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ConditionNotificationOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
